==> %E5%88%A4%E5%88%86%E7%82%B9V2.0.zip: fe_judgmentpoint/src/utils/api.js <==
let host = ''
// 科大接口切换，参数里带host的为科大，否则就是职站中台
let isKd = /&host=(\d)/.exec(location.hash) //host：{1：测试环境，2：正式环境}
if(isKd){
    host = isKd[1] == 1 ? 'http://122.9.154.146' : 'http://116.63.168.79'
}else{
    let url = location.host;
    // 职站中台接口切换
    if(url.includes('120.78.198.231')){
        host = 'http://120.78.198.231'; // 职站测试服
    }else if(url.includes('occupationlab.com')){
        host = 'http://www.occupationlab.com'; // 职站正式服
    }else if(url.includes('10.196.131.73')){
        host = 'http://10.196.131.73'; // 河海版
    }else if (url.includes('124.71.12.62')) {
        host = 'http://124.71.12.62'; // 巢湖版
    } else if (url.includes('39.108.250.202')) {
        host = 'http://39.108.250.202:9000'; // 中台测试服
    } else {
        console.log("本地-中台测试服");
        host = 'http://39.108.250.202:9000';
    }

    // host = 'http://192.168.31.137:9000' // 坤
}
let host1 = 'http://39.108.250.202:8080';
let uploadURL = 'http://8.134.8.197:8001';
export default {
    fileupload: `${uploadURL}/oss/manage/fileupload`,

    // 交易类（流程类）
    getLcRecord: `${host}/judgment/lcRecord/getLcRecord`, // 获取流程记录列表(树)
    getSubjectInfo: `${host}/judgment/lcSubject/getSubjectInfo`, // 根据题目id获取题目信息
    addJudgmentRule: `${host}/judgment/lcJudgmentRule/addJudgmentRule`, // 添加判分点规则
    updateJudgmentRule: `${host}/judgment/lcJudgmentRule/updateJudgmentRule`, // 添加判分点规则
    deleteJudgmentRule: `${host}/judgment/lcJudgmentRule/deleteJudgmentRule`, // 批量删除判分点规则
    addJudgmentPoint: `${host}/judgment/lcJudgmentPoint/addJudgmentPoint`, // 新增判分点
    updateJudgmentPoint: `${host}/judgment/lcJudgmentPoint/updateJudgmentPoint`, // 更新判分点
    deleteJudgmentPoint: `${host}/judgment/lcJudgmentPoint/deleteJudgmentPoint`, // 批量删除判分点
    calculate: `${host}/judgment/lcJudgmentPoint/calculate`, // 计算判分点规则
    updateIsOpen: `${host}/judgment/lcJudgmentPoint/updateIsOpen`, // 更新开启状态
    queryNameIsExist: `${host}/judgment/lcJudgmentPoint/queryNameIsExist`, // 新增/编辑判分点名称判重
    bandingProject: `${host}/judgment/lcJudgmentPoint/bandingProject`, // 绑定项目管理
    queryAllJudgmentPoint: `${host}/judgment/lcJudgmentPoint/queryAllJudgmentPoint`, // 获取流程类判分点列表
    queryJudgmentPointDetails: `${host}/judgment/lcJudgmentPoint/queryJudgmentPointDetails`, // 获取判分点详细信息

    // 编程类
    getBcJudgmentPoint: `${host}/judgment/bcJudgmentPoint/getBcJudgmentPoint`, // 获取判分点列表(分页)
    queryBcJudgmentPointByBcId: `${host}/judgment/bcJudgmentPoint/queryBcJudgmentPointByBcId`, // 根据判分点id查询判分点详细信息
    queryBcJudgmentByBcId: `${host}/judgment/bcJudgmentPoint/queryBcJudgmentByBcId`, // 根据判分点id查询判分点信息(不带规则)
    addBcJudgmentPoint: `${host}/judgment/bcJudgmentPoint/addBcJudgmentPoint`, // 添加判分点
    updateBcJudgmentPoint: `${host}/judgment/bcJudgmentPoint/updateBcJudgmentPoint`, // 更新判分点
    bcDeleteJudgmentPoint: `${host}/judgment/bcJudgmentPoint/deleteJudgmentPoint`, // 批量删除判分点
    bcQueryNameIsExist: `${host}/judgment/bcJudgmentPoint/queryNameIsExist`, // 新增/编辑判分点名称判重
    bcBandingProject: `${host}/judgment/bcJudgmentPoint/bcBandingProject`, // 绑定项目管理
    bcUpdateIsOpen: `${host}/judgment/bcJudgmentPoint/updateIsOpen`, // 更新开启状态
    bcAddJudgmentRule: `${host}/judgment/bcJudgmentRule/addJudgmentRule`, // 添加判分点规则
    bcUpdateJudgmentRule: `${host}/judgment/bcJudgmentRule/updateJudgmentRule`, // 更新判分点规则
    bcDeleteJudgmentRule: `${host}/judgment/bcJudgmentRule/deleteJudgmentRule`, // 批量删除判分点规则


    // 职站
    QueryPointOfJudgement: `${host}/judgment/pointOfJudgement/queryPointOfJudgement`, //判分点列表查询
    DeletePointOfJudgement: `${host}/judgment/pointOfJudgement/deletePointOfJudgement`, //判分点列表删除
    QueryPfdInformation: `${host}/judgment/pointOfJudgement/queryPfdInformation`, //判分点详细信息
    UpdatePointOfJudgement: `${host}/judgment/pointOfJudgement/updatePointOfJudgement`, //编辑判分点基本信息
    UpdatePointOfJudgementRule: `${host}/judgment/pointOfJudgement/updatePointOfJudgementRule`, //编辑判分点规则
    AddPfdgzInformation: `${host}/judgment/pointOfJudgement/addPfdgzInformation`, //新增判分规则
    AddPfdInformation: `${host}/judgment/pointOfJudgement/addPfdInformation`, //新增判分点基本信息
    QueryPfdgzInformation: `${host}/judgment/pointOfJudgement/queryPfdgzInformation`, //判分点规则信息查询
    QueryAddgz: `${host}/judgment/pointOfJudgement/queryAddgz`, //查询新增判分点规则新增的数据
    DeletePointOfJudgementRule: `${host}/judgment/pointOfJudgement/deletePointOfJudgementRule`, //删除判分点规则
    JudgmentPointNameRepetition: `${host}/judgment/pointOfJudgement/JudgmentPointNameRepetition`,




    UpdateIsOpen: `${host}/judgment/pointOfJudgement/updateIsOpen`, //修改判分点状态
    queryUserIds:`${host}/liuwanr/userInfo/queryUserIds`,


    // 科大子系统
    queryPoint: `${host}/kdSys/queryPoint`,
    querySubject: `${host}/kdSys/querySubject`,
    queryItem: `${host}/kdSys/queryItem`,

    // 科大平台
    queryListTrading: `${host}/judgment/tradingJudgmentPoints/query`,
    deleteTrading: `${host}/judgment/tradingJudgmentPoints/delete`,
    addTrading: `${host}/judgment/tradingJudgmentPoints/add`,
    queryDetailsTrading: `${host}/judgment/tradingJudgmentPoints/queryDetails`,
    updateTrading: `${host}/judgment/tradingJudgmentPoints/update`,
    updateRuleTrading: `${host}/judgment/tradingJudgmentPoints/updateRule`,
    deleteRuleTrading: `${host}/judgment/tradingJudgmentPoints/deleteRule`,
    addRule: `${host}/judgment/tradingJudgmentPoints/addRule`,

    // 川大子系统
    firstLevel: `${host1}/sichuan/point/firstLevel`,
    secondaryLevel: `${host1}/sichuan/point/secondaryLevel`,
    thirdLevel: `${host1}/sichuan/point/thirdLevel`,
}

==> %E5%88%A4%E5%88%86%E7%82%B9V2.2.zip: fe_judgmentpoint/src/utils/api.js <==
let host = ''
// 科大接口切换，参数里带host的为科大，否则就是职站中台
let isKd = /&host=(\d)/.exec(location.hash) //host：{1：测试环境，2：正式环境}
if(isKd){
    host = isKd[1] == 1 ? 'http://122.9.154.146' : 'http://116.63.168.79'
}else{
    let url = location.host;
    // 职站中台接口切换
    if(url.includes('120.78.198.231')){
        host = 'http://120.78.198.231'; // 职站测试服
    }else if(url.includes('occupationlab.com')){
        host = 'http://www.occupationlab.com'; // 职站正式服
    }else if(url.includes('10.196.131.73')){
        host = 'http://10.196.131.73'; // 河海版
    }else if (url.includes('124.71.12.62')) {
        host = 'http://124.71.12.62:9000'; // 巢湖版
    } else if (url.includes('39.108.250.202')) {
        host = 'http://39.108.250.202:9000'; // 中台测试服
    }  else if (url.includes('www.huorantech.cn')) {
        host = 'http://www.huorantech.cn:9000'; // 中台线上
    } else {
        console.log("本地-中台测试服");
        host = 'http://39.108.250.202:9000'; //线上
        // host = 'http://192.168.31.137:9000'; //赓
    }

    // host = 'http://192.168.31.137:9000' // 坤
}
let host1 = 'http://39.108.250.202:8080';
let uploadURL = `${location.origin}:9000`
export default {
    fileupload: `${uploadURL}/oss/manage/fileupload`,

    // 交易类（流程类）
    getLcRecord: `${host}/judgment/lcRecord/getLcRecord`, // 获取流程记录列表(树)
    getSubjectInfo: `${host}/judgment/lcSubject/getSubjectInfo`, // 根据题目id获取题目信息
    addJudgmentRule: `${host}/judgment/lcJudgmentRule/addJudgmentRule`, // 添加判分点规则
    updateJudgmentRule: `${host}/judgment/lcJudgmentRule/updateJudgmentRule`, // 添加判分点规则
    deleteJudgmentRule: `${host}/judgment/lcJudgmentRule/deleteJudgmentRule`, // 批量删除判分点规则
    addJudgmentPoint: `${host}/judgment/lcJudgmentPoint/addJudgmentPoint`, // 新增判分点
    updateJudgmentPoint: `${host}/judgment/lcJudgmentPoint/updateJudgmentPoint`, // 更新判分点
    deleteJudgmentPoint: `${host}/judgment/lcJudgmentPoint/deleteJudgmentPoint`, // 批量删除判分点
    calculate: `${host}/judgment/lcJudgmentPoint/calculate`, // 计算判分点规则
    updateIsOpen: `${host}/judgment/lcJudgmentPoint/updateIsOpen`, // 更新开启状态
    queryNameIsExist: `${host}/judgment/lcJudgmentPoint/queryNameIsExist`, // 新增/编辑判分点名称判重
    bandingProject: `${host}/judgment/lcJudgmentPoint/bandingProject`, // 绑定项目管理
    queryAllJudgmentPoint: `${host}/judgment/lcJudgmentPoint/queryAllJudgmentPoint`, // 获取流程类判分点列表
    queryJudgmentPointDetails: `${host}/judgment/lcJudgmentPoint/queryJudgmentPointDetails`, // 获取判分点详细信息

    // 编程类
    getBcJudgmentPoint: `${host}/judgment/bcJudgmentPoint/getBcJudgmentPoint`, // 获取判分点列表(分页)
    queryBcJudgmentPointByBcId: `${host}/judgment/bcJudgmentPoint/queryBcJudgmentPointByBcId`, // 根据判分点id查询判分点详细信息
    queryBcJudgmentByBcId: `${host}/judgment/bcJudgmentPoint/queryBcJudgmentByBcId`, // 根据判分点id查询判分点信息(不带规则)
    addBcJudgmentPoint: `${host}/judgment/bcJudgmentPoint/addBcJudgmentPoint`, // 添加判分点
    updateBcJudgmentPoint: `${host}/judgment/bcJudgmentPoint/updateBcJudgmentPoint`, // 更新判分点
    bcDeleteJudgmentPoint: `${host}/judgment/bcJudgmentPoint/deleteJudgmentPoint`, // 批量删除判分点
    bcQueryNameIsExist: `${host}/judgment/bcJudgmentPoint/queryNameIsExist`, // 新增/编辑判分点名称判重
    bcBandingProject: `${host}/judgment/bcJudgmentPoint/bcBandingProject`, // 绑定项目管理
    bcUpdateIsOpen: `${host}/judgment/bcJudgmentPoint/updateIsOpen`, // 更新开启状态
    bcAddJudgmentRule: `${host}/judgment/bcJudgmentRule/addJudgmentRule`, // 添加判分点规则
    bcUpdateJudgmentRule: `${host}/judgment/bcJudgmentRule/updateJudgmentRule`, // 更新判分点规则
    bcDeleteJudgmentRule: `${host}/judgment/bcJudgmentRule/deleteJudgmentRule`, // 批量删除判分点规则


    // 职站
    QueryPointOfJudgement: `${host}/judgment/pointOfJudgement/queryPointOfJudgement`, //判分点列表查询
    DeletePointOfJudgement: `${host}/judgment/pointOfJudgement/deletePointOfJudgement`, //判分点列表删除
    QueryPfdInformation: `${host}/judgment/pointOfJudgement/queryPfdInformation`, //判分点详细信息
    UpdatePointOfJudgement: `${host}/judgment/pointOfJudgement/updatePointOfJudgement`, //编辑判分点基本信息
    UpdatePointOfJudgementRule: `${host}/judgment/pointOfJudgement/updatePointOfJudgementRule`, //编辑判分点规则
    AddPfdgzInformation: `${host}/judgment/pointOfJudgement/addPfdgzInformation`, //新增判分规则
    AddPfdInformation: `${host}/judgment/pointOfJudgement/addPfdInformation`, //新增判分点基本信息
    QueryPfdgzInformation: `${host}/judgment/pointOfJudgement/queryPfdgzInformation`, //判分点规则信息查询
    QueryAddgz: `${host}/judgment/pointOfJudgement/queryAddgz`, //查询新增判分点规则新增的数据
    DeletePointOfJudgementRule: `${host}/judgment/pointOfJudgement/deletePointOfJudgementRule`, //删除判分点规则
    JudgmentPointNameRepetition: `${host}/judgment/pointOfJudgement/JudgmentPointNameRepetition`,




    UpdateIsOpen: `${host}/judgment/pointOfJudgement/updateIsOpen`, //修改判分点状态
    queryUserIds:`${host}/liuwanr/userInfo/queryUserIds`,


    // 科大子系统
    queryPoint: `${host}/kdSys/queryPoint`,
    querySubject: `${host}/kdSys/querySubject`,
    queryItem: `${host}/kdSys/queryItem`,

    // 科大平台
    queryListTrading: `${host}/judgment/tradingJudgmentPoints/query`,
    deleteTrading: `${host}/judgment/tradingJudgmentPoints/delete`,
    addTrading: `${host}/judgment/tradingJudgmentPoints/add`,
    queryDetailsTrading: `${host}/judgment/tradingJudgmentPoints/queryDetails`,
    updateTrading: `${host}/judgment/tradingJudgmentPoints/update`,
    updateRuleTrading: `${host}/judgment/tradingJudgmentPoints/updateRule`,
    deleteRuleTrading: `${host}/judgment/tradingJudgmentPoints/deleteRule`,
    addRule: `${host}/judgment/tradingJudgmentPoints/addRule`,

    // 川大子系统
    firstLevel: `${host1}/sichuan/point/firstLevel`,
    secondaryLevel: `${host1}/sichuan/point/secondaryLevel`,
    thirdLevel: `${host1}/sichuan/point/thirdLevel`,
}
